# pygdshort

pygdshort is a python library for shortening URLs using the is.gd API.

## Installation

`pip install pygdshort`

## Usage

For usage see the [wiki](https://github.com/TheOctoGirl/pygdshort/wiki).
